@@ -97,7 +97,7 @@ class BaseRepresenter(object):
         """
         David Fraser: Extract a method to represent keys in mappings, so that
         a subclass can choose not to quote them (for example)
-        used in repesent_mapping
+        used in represent_mapping
         https://bitbucket.org/davidfraser/pyyaml/commits/d81df6eb95f20cac4a79eed95ae553b5c6f77b8c
         """
         return self.represent_data(data)
@@ -660,6 +660,7 @@ class RoundTripRepresenter(SafeRepresenter):
 
     def represent_key(self, data):
         if isinstance(data, CommentedKeySeq):
+            self.alias_key = None
             return self.represent_sequence(u'tag:yaml.org,2002:seq', data,
                                            flow_style=True)
         return SafeRepresenter.represent_key(self, data)
